package config

import (
	"fmt"
	"log"

	"git.downtown8.com/golang/common/conf"
	"git.downtown8.com/rms/g-common/g-common/metrics"
	"git.downtown8.com/rms/g-common/g-common/redis"
	"github.com/spf13/viper"
)

type Config struct {
	Application    ApplicationInfo `yaml:"application"`
	OrderCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"orderCenterSvc"`
	BrandStoreCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"brandStoreCenterSvc"`
	ProductCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"productCenterSvc"`
	KitchenCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"kitchenCenterSvc"`
	PublicCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"publicCenterSvc"`
	MessageCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"messageCenterSvc"`
	UserCenterSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"userCenterSvc"`
	PrinterMiddleSvc struct {
		Name string `yaml:"name"`
		Addr string `yaml:"addr"`
		Port int    `yaml:"port"`
	} `yaml:"printerMiddleSvc"`
	Redis    redis.Config   `yaml:"redis"`
	Temporal *WfConfig      `yaml:"temporal"`
	RabbitMq *RabbitMq      `yaml:"rabbitMq"`
	Otel     metrics.Config `yaml:"otel"`
	Novu     *Novu          `yaml:"novu"`
}

type RabbitMq struct {
	Host       string     `yaml:"host"`
	Port       int        `yaml:"port"`
	UserName   string     `yaml:"username"`
	Password   string     `yaml:"password"`
	Vhost      string     `yaml:"vhost"` // 特殊处理
	Publisher  *Publisher `yaml:"publisher"`
	ChannelNum int        `yaml:"channelNum"`
}
type Publisher struct {
	Confirms bool `json:"confirms"`
	Returns  bool `json:"returns"`
}

type WfConfig struct {
	Namespace                        string `yaml:"namespace"`
	HostPort                         string `yaml:"hostPort"`
	Vhost                            string `yaml:"vhost"` // 特殊处理
	MaxConcurrentWorkflowTaskPollers int    `yaml:"maxConcurrentWorkflowTaskPollers"`
	MaxConcurrentActivityTaskPollers int    `yaml:"maxConcurrentActivityTaskPollers"`
	MaxConcurrentNexusTaskPollers    int    `yaml:"maxConcurrentNexusTaskPollers"`
}

type ApplicationInfo struct {
	Version     string `yaml:"version"`
	Name        string `yaml:"name"`
	Environment string `yaml:"environment"`
	Host        string `yaml:"host"`
}

type Novu struct {
	ApiKey           string `yaml:"apiKey"`
	BackendURL       string `yaml:"backendURL"`
	SubscriberPrefix string `yaml:"subscriberPrefix"`
}

func Load(path string) Config {
	var c Config
	err := conf.LoadFile(path, &c)
	if err != nil {
		log.Fatalf("error: config file %s, %s", path, err.Error())
	}
	viper.AutomaticEnv()
	vhost := viper.GetString("RABBIT_VHOST") // 读取环境变量的vhost
	if vhost == "" {
		fmt.Println("未解析到RABBIT_VHOST")
		c.RabbitMq.Vhost = "devv1"
		c.Temporal.Vhost = "local"
	} else {
		c.RabbitMq.Vhost = vhost
		c.Temporal.Vhost = vhost
		vhost = "devv1"
	}
	return c
}
