package brand_store

import (
	"context"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userCenter"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userpermit"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/brand"
	"git.downtown8.com/rms/g-common/g-common/constants/errorcode"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/message/rabbitmq"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/message/rabbitmq/producer"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqBrand"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqBrandStoreCenter"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqBrandStoreCenter/hqbrandstoreservice"
	"github.com/cloudwego/kitex/server"
	"github.com/jinzhu/copier"
)

type BrandService struct {
	rpcClient *rpcclient.Client
	mq        *rabbitmq.Client
}

func NewBrandService(client *rpcclient.Client, rc *rabbitmq.Client) *BrandService {
	o := &BrandService{
		rpcClient: client,
		mq:        rc,
	}
	return o
}

func RegistryBrand(svc *BrandService) func(svr server.Server) error {
	return func(svr server.Server) error {
		return hqbrandstoreservice.RegisterService(svr, svc)
	}
}

func (b *BrandService) CreateBrand(ctx context.Context, req *hqBrand.CreateBrandRequest) (res *hqBrand.CreateBrandResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.CreateBrand(ctx, &brand.CreateBrandRequest{
		BrandName: req.GetBrandName(),
		Logo:      req.GetLogo(),
	})
	if err != nil {
		return &hqBrand.CreateBrandResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	if r.GetCode() != errorcode.SUCCESS {
		return &hqBrand.CreateBrandResponse{
			Code: r.GetCode(),
			Msg:  r.GetMsg(),
		}, nil
	}

	initUserBrandResp, err := b.rpcClient.UserCenter.InitUserBrand(ctx, &userCenter.UserCenterInitUserBrandReq{
		BrandId: int64(r.GetData().GetBrandId()),
		UserId:  req.GetUserId(),
	})
	if err != nil {
		return &hqBrand.CreateBrandResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	if initUserBrandResp.GetCode() == errorcode.SUCCESS {
		b.mq.Producer.PublishCreateBrand(ctx, &producer.CreateBrandPayload{
			RuleId:  initUserBrandResp.GetData().GetRuleId(),
			BizType: initUserBrandResp.GetData().GetBizType(),
			Payload: initUserBrandResp.GetData().GetPayload(),
		})
	}

	data := new(hqBrand.CreateBrandResponseData)
	copier.Copy(data, r.GetData())
	return &hqBrand.CreateBrandResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) DetailBrand(ctx context.Context, req *hqBrand.DetailBrandRequest) (res *hqBrand.DetailBrandResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailBrand(ctx, &brand.DetailBrandRequest{
		BrandId: req.GetBrandId(),
	})
	if err != nil {
		return &hqBrand.DetailBrandResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqBrand.Brand)
	copier.Copy(data, r.GetData())
	return &hqBrand.DetailBrandResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}
func (b *BrandService) UpdateBrand(ctx context.Context, req *hqBrand.UpdateBrandRequest) (res *hqBrand.UpdateBrandResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UpdateBrand(ctx, &brand.UpdateBrandRequest{
		BrandId:   req.GetBrandId(),
		BrandName: req.GetBrandName(),
		Logo:      req.GetLogo(),
		Status:    req.GetStatus(),
	})
	if err != nil {
		return &hqBrand.UpdateBrandResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	if r.GetCode() != errorcode.SUCCESS {
		b.mq.Producer.PublishUpdateBrand(ctx, &producer.UpdateBrandPayload{
			BrandId:   req.GetBrandId(),
			BrandName: req.GetBrandName(),
			Logo:      req.GetLogo(),
			Status:    req.GetStatus(),
		})
	}
	return &hqBrand.UpdateBrandResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}
func (b *BrandService) ListBrandWithStoreCnt(ctx context.Context, req *hqBrandStoreCenter.ListBrandWithStoreCntRequest) (res *hqBrandStoreCenter.ListBrandWithStoreCntResponse, err error) {
	brandList, err := b.rpcClient.UserCenter.CurrentUserBrandStoresV3(ctx, &userpermit.CurrentUserBrandStoresRequest{
		UserId: req.GetUserId(),
	})
	if err != nil {
		return &hqBrandStoreCenter.ListBrandWithStoreCntResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	if brandList.GetCode() != 0 {
		return &hqBrandStoreCenter.ListBrandWithStoreCntResponse{
			Code: brandList.GetCode(),
			Msg:  brandList.GetMsg(),
		}, nil
	}
	var brandIds []int32
	for _, v := range brandList.GetData().GetBrandStores() {
		brandIds = append(brandIds, v.GetBrandId())
	}
	if len(brandIds) == 0 {
		return &hqBrandStoreCenter.ListBrandWithStoreCntResponse{
			Code: errorcode.SUCCESS,
			Msg:  errorcode.SUCCESS_MSG,
			Data: nil,
		}, nil
	}
	r, err := b.rpcClient.BrandStoreCenter.ListBrand(ctx, &brand.ListBrandRequest{
		BrandIds: brandIds,
	})
	if err != nil {
		return &hqBrandStoreCenter.ListBrandWithStoreCntResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqBrandStoreCenter.ListBrandWithStoreCntResponseData)
	copier.Copy(data, r.GetData())
	return &hqBrandStoreCenter.ListBrandWithStoreCntResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}
