package brand_store

import (
	"context"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userCenter"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userpermit"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/store"
	"git.downtown8.com/rms/g-common/g-common/constants/errorcode"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/message/rabbitmq/producer"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqStore"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/moduleModel"
	"git.downtown8.com/rms/public/hera/kitex_gen/todo"
	"github.com/jinzhu/copier"
)

func (b *BrandService) DetailStoreBusiness(ctx context.Context, req *hqStore.DetailStoreBusinessRequest) (res *hqStore.DetailStoreBusinessResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStoreBusiness(ctx, &store.DetailStoreBusinessRequest{
		BrandId:      req.GetBrandId(),
		StoreId:      req.GetStoreId(),
		BusinessType: req.GetBusinessType(),
	})
	if err != nil {
		return &hqStore.DetailStoreBusinessResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.StoreBusiness)
	copier.Copy(data, r.GetData())
	return &hqStore.DetailStoreBusinessResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) ListStoreBusiness(ctx context.Context, req *hqStore.ListStoreBusinessRequest) (res *hqStore.ListStoreBusinessResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.ListStoreBusiness(ctx, &store.ListStoreBusinessRequest{
		BrandId:  req.GetBrandId(),
		StoreIds: []int32{req.GetStoreId()},
	})
	if err != nil {
		return &hqStore.ListStoreBusinessResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.ListStoreBusinessResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.ListStoreBusinessResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UpdateStoreBusiness(ctx context.Context, req *hqStore.UpdateStoreBusinessRequest) (res *hqStore.UpdateStoreBusinessResponse, err error) {
	newReq := new(store.UpdateStoreBusinessRequest)
	copier.Copy(newReq, req)
	r, err := b.rpcClient.BrandStoreCenter.UpdateStoreBusiness(ctx, newReq)
	if err != nil {
		return &hqStore.UpdateStoreBusinessResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.UpdateStoreBusinessResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) CreateStoreBusiness(ctx context.Context, req *hqStore.CreateStoreBusinessRequest) (res *hqStore.CreateStoreBusinessResponse, err error) {
	newReq := new(store.CreateStoreBusinessRequest)
	copier.Copy(newReq, req)
	r, err := b.rpcClient.BrandStoreCenter.CreateStoreBusiness(ctx, newReq)
	if err != nil {
		return &hqStore.CreateStoreBusinessResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.CreateStoreBusinessResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DeleteStoreBusiness(ctx context.Context, req *hqStore.DeleteStoreBusinessRequest) (res *hqStore.DeleteStoreBusinessResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DeleteStoreBusiness(ctx, &store.DeleteStoreBusinessRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
		Id:      req.GetId(),
	})
	if err != nil {
		return &hqStore.DeleteStoreBusinessResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.DeleteStoreBusinessResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) CreateStore(ctx context.Context, req *hqStore.CreateStoreRequest) (res *hqStore.CreateStoreResponse, err error) {
	newReq := new(store.CreateStoreRequest)
	copier.Copy(newReq, req)
	r, err := b.rpcClient.BrandStoreCenter.CreateStore(ctx, newReq)
	if err != nil {
		return &hqStore.CreateStoreResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	data := new(hqStore.CreateStoreResponseData)
	copier.Copy(data, r.GetData())

	if r.GetCode() == errorcode.SUCCESS {
		// 初始化门店权限
		go func() {
			_, _ = b.rpcClient.UserCenter.InitUserStore(context.Background(), &userCenter.UserCenterInitUserStoreReq{
				BrandId: int64(r.GetData().GetBrandId()),
				StoreId: int64(r.GetData().GetStoreId()),
				UserId:  req.GetUserId(),
			})
		}()
		// 发送消息
		b.mq.Producer.PublishCreateStore(ctx, &producer.CreateStorePayload{
			BrandId:   r.GetData().GetBrandId(),
			StoreId:   r.GetData().GetStoreId(),
			StoreName: r.GetData().GetStoreName(),
		})
		// 创建新手引导任务
		todoDefaultCreateResp, err := b.rpcClient.PublicCenter.TodoDefaultCreate(context.Background(), &todo.TodoDefaultCreateReq{
			BrandId: r.GetData().GetBrandId(),
			StoreId: r.GetData().GetStoreId(),
		})
		if err != nil || todoDefaultCreateResp.GetCode() != errorcode.SUCCESS {
			return &hqStore.CreateStoreResponse{
				Code: r.GetCode(),
				Msg:  r.GetMsg(),
				Data: data,
			}, nil
		}

		var giveAuthPackageItems []*moduleModel.GiveAuthPackageItem
		for _, v := range todoDefaultCreateResp.GetData().GetStoreModule() {
			giveAuthPackageItems = append(giveAuthPackageItems, &moduleModel.GiveAuthPackageItem{
				BizId:      todoDefaultCreateResp.GetData().GetBizId(),
				PackageKey: v.GetSaleModuleKey(),
				Days:       v.GetDays(),
			})
		}

		_, _ = b.rpcClient.OnlineSalesCenter.GiveAuthPackage(context.Background(), &moduleModel.GiveAuthPackageRequest{
			BrandId:              r.GetData().GetBrandId(),
			StoreId:              r.GetData().GetStoreId(),
			Name:                 todoDefaultCreateResp.GetData().GetName(),
			GiveAuthPackageItems: giveAuthPackageItems,
		})

	}

	return &hqStore.CreateStoreResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) ListStore(ctx context.Context, req *hqStore.ListStoreRequest) (res *hqStore.ListStoreResponse, err error) {
	brandList, err := b.rpcClient.UserCenter.CurrentUserBrandStoresV3(ctx, &userpermit.CurrentUserBrandStoresRequest{
		UserId:  req.GetUserId(),
		BrandId: req.GetBrandId(),
	})
	if err != nil {
		return &hqStore.ListStoreResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	if brandList.GetCode() != 0 {
		return &hqStore.ListStoreResponse{
			Code: brandList.GetCode(),
			Msg:  brandList.GetMsg(),
		}, nil
	}
	var storeIds []int32
	var futureStore bool
	for _, v := range brandList.GetData().GetBrandStores() {
		if !v.FutureStore {
			storeIds = append(storeIds, v.GetStoreIds()...)
		}
		futureStore = v.FutureStore
	}
	if len(storeIds) == 0 && !futureStore {
		return &hqStore.ListStoreResponse{
			Code: errorcode.SUCCESS,
			Msg:  errorcode.SUCCESS_MSG,
			Data: nil,
		}, nil
	}

	r, err := b.rpcClient.BrandStoreCenter.ListStore(ctx, &store.ListStoreRequest{
		BrandId:  req.GetBrandId(),
		StoreIds: storeIds,
	})
	if err != nil {
		return &hqStore.ListStoreResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.ListStoreResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.ListStoreResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) ListStoreWithDeleted(ctx context.Context, req *hqStore.ListStoreWithDeletedRequest) (res *hqStore.ListStoreWithDeletedResponse, err error) {
	// fixme: isDel
	brandList, err := b.rpcClient.UserCenter.CurrentUserBrandStoresV3(ctx, &userpermit.CurrentUserBrandStoresRequest{
		UserId:  req.GetUserId(),
		BrandId: req.GetBrandId(),
	})
	if err != nil {
		return &hqStore.ListStoreWithDeletedResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	if brandList.GetCode() != 0 {
		return &hqStore.ListStoreWithDeletedResponse{
			Code: brandList.GetCode(),
			Msg:  brandList.GetMsg(),
		}, nil
	}
	var storeIds []int32
	var futureStore bool
	for _, v := range brandList.GetData().GetBrandStores() {
		if !v.FutureStore {
			storeIds = append(storeIds, v.GetStoreIds()...)
		}
		futureStore = v.FutureStore
	}
	if len(storeIds) == 0 && !futureStore {
		return &hqStore.ListStoreWithDeletedResponse{
			Code: errorcode.SUCCESS,
			Msg:  errorcode.SUCCESS_MSG,
			Data: nil,
		}, nil
	}

	r, err := b.rpcClient.BrandStoreCenter.ListStoreWithDeleted(ctx, &store.ListStoreWithDeletedRequest{
		BrandId:  req.GetBrandId(),
		StoreIds: storeIds,
	})
	if err != nil {
		return &hqStore.ListStoreWithDeletedResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.ListStoreWithDeletedResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.ListStoreWithDeletedResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UpdateStore(ctx context.Context, req *hqStore.UpdateStoreRequest) (res *hqStore.UpdateStoreResponse, err error) {
	newReq := new(store.UpdateStoreRequest)
	copier.Copy(newReq, req)
	r, err := b.rpcClient.BrandStoreCenter.UpdateStore(ctx, newReq)
	if err != nil {
		return &hqStore.UpdateStoreResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.UpdateStoreResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) UpdateStorePlate(ctx context.Context, req *hqStore.StorePlateRequest) (res *hqStore.StorePlateResponse, err error) {
	newReq := new(store.StorePlateRequest)
	copier.Copy(newReq, req)
	r, err := b.rpcClient.BrandStoreCenter.UpdateStorePlate(ctx, newReq)
	if err != nil {
		return &hqStore.StorePlateResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.StorePlateResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DeleteStore(ctx context.Context, req *hqStore.DeleteStoreRequest) (res *hqStore.DeleteStoreResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DeleteStore(ctx, &store.DeleteStoreRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
	})
	if err != nil {
		return &hqStore.DeleteStoreResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.DeleteStoreResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.DeleteStoreResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) DetailStore(ctx context.Context, req *hqStore.DetailStoreRequest) (res *hqStore.DetailStoreResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStore(ctx, &store.DetailStoreRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
	})
	if err != nil {
		return &hqStore.DetailStoreResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.Store)
	copier.Copy(data, r.GetData())
	return &hqStore.DetailStoreResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) DetailStoreWithBusiness(ctx context.Context, req *hqStore.DetailStoreWithBusinessRequest) (res *hqStore.DetailStoreWithBusinessResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStoreWithBusiness(ctx, &store.DetailStoreWithBusinessRequest{
		BrandId:      req.GetBrandId(),
		StoreId:      req.GetStoreId(),
		BusinessType: req.GetBusinessType(),
	})
	if err != nil {
		return &hqStore.DetailStoreWithBusinessResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.DetailStoreWithBusinessResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.DetailStoreWithBusinessResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UpdateStoreOrderMethod(ctx context.Context, req *hqStore.UpdateStoreOrderMethodRequest) (res *hqStore.UpdateStoreOrderMethodResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UpdateStoreOrderMethod(ctx, &store.UpdateStoreOrderMethodRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
		OrderMethod: &store.StoreOrderMethod{
			Client:     req.GetOrderMethod().GetClient(),
			Scene:      req.GetOrderMethod().GetScene(),
			PayModel:   req.GetOrderMethod().GetPayModel(),
			DiningMode: req.GetOrderMethod().GetDiningMode(),
		},
	})
	if err != nil {
		return &hqStore.UpdateStoreOrderMethodResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.StoreOrderMethod)
	copier.Copy(data, r.GetData())
	return &hqStore.UpdateStoreOrderMethodResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) DownloadStoreCode(ctx context.Context, req *hqStore.DownloadStoreCodeRequest) (res *hqStore.DownloadStoreCodeResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DownloadStoreCode(ctx, &store.DownloadStoreCodeRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
		Type:    req.GetType(),
	})
	if err != nil {
		return &hqStore.DownloadStoreCodeResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.DownloadStoreCodeResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.DownloadStoreCodeResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UploadBusinessQualifications(ctx context.Context, req *hqStore.UploadBusinessQualificationsRequest) (res *hqStore.UploadBusinessQualificationsResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UploadBusinessQualifications(ctx, &store.UploadBusinessQualificationsRequest{
		BrandId:                req.GetBrandId(),
		StoreId:                req.GetStoreId(),
		BusinessQualifications: req.GetBusinessQualifications(),
	})
	if err != nil {
		return &hqStore.UploadBusinessQualificationsResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.UploadBusinessQualificationsResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DetailStoreOrderMethod(ctx context.Context, req *hqStore.DetailStoreOrderMethodRequest) (res *hqStore.DetailStoreOrderMethodResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStore(ctx, &store.DetailStoreRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
	})
	if err != nil {
		return &hqStore.DetailStoreOrderMethodResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	data := new(hqStore.DetailStoreOrderMethodResponseData)
	for _, v := range r.GetData().GetStoreOrderMethod() {
		if v.Client == req.GetClient() {
			data.OrderMethod = &hqStore.StoreOrderMethod{
				Client:     v.GetClient(),
				Scene:      v.GetScene(),
				PayModel:   v.GetPayModel(),
				DiningMode: v.GetDiningMode(),
			}
		}
	}
	return &hqStore.DetailStoreOrderMethodResponse{
		Code: errorcode.SUCCESS,
		Msg:  errorcode.SUCCESS_MSG,
		Data: data,
	}, nil
}

func (b *BrandService) ListStoreOrderMethod(ctx context.Context, req *hqStore.ListStoreOrderMethodRequest) (res *hqStore.ListStoreOrderMethodResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStore(ctx, &store.DetailStoreRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
	})
	if err != nil {
		return &hqStore.ListStoreOrderMethodResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	data := new(hqStore.ListStoreOrderMethodResponseData)
	for _, v := range r.GetData().GetStoreOrderMethod() {
		data.List = append(data.List, &hqStore.StoreOrderMethod{
			Client:     v.GetClient(),
			Scene:      v.GetScene(),
			PayModel:   v.GetPayModel(),
			DiningMode: v.GetDiningMode(),
		})
	}
	return &hqStore.ListStoreOrderMethodResponse{
		Code: errorcode.SUCCESS,
		Msg:  errorcode.SUCCESS_MSG,
		Data: data,
	}, nil
}

func (b *BrandService) SetOrderPath(ctx context.Context, req *hqStore.SetOrderPathRequest) (res *hqStore.SetOrderPathResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.SetOrderPath(ctx, &store.SetOrderPathRequest{
		BrandId:   req.GetBrandId(),
		StoreId:   req.GetStoreId(),
		OrderPath: req.GetOrderPath(),
	})
	if err != nil {
		return &hqStore.SetOrderPathResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.SetOrderPathResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DetailOrderPath(ctx context.Context, req *hqStore.DetailOrderPathRequest) (res *hqStore.DetailOrderPathResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStore(ctx, &store.DetailStoreRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
	})
	if err != nil {
		return &hqStore.DetailOrderPathResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.DetailOrderPathResponse{
		Code: errorcode.SUCCESS,
		Msg:  errorcode.SUCCESS_MSG,
		Data: &hqStore.DetailOrderPathResponseData{OrderPath: r.GetData().GetOrderPath()},
	}, nil
}
