package brand_store

import (
	"context"
	"fmt"
	"git.downtown8.com/rms/g-mq/hera/kitex_gen/messageCenter"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqBrandStoreCenter"

	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/store"
	"git.downtown8.com/rms/g-common/g-common/constants/errorcode"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqStore"
	"github.com/jinzhu/copier"
)

func (b *BrandService) SetStoreTableConfig(ctx context.Context, req *hqStore.SetStoreTableConfigRequest) (res *hqStore.SetStoreTableConfigResponse, err error) {
	newReq := new(store.SetStoreTableConfigRequest)
	r, err := b.rpcClient.BrandStoreCenter.SetStoreTableConfig(ctx, newReq)
	if err != nil {
		return &hqStore.SetStoreTableConfigResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.SetStoreTableConfigResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DetailStoreTableConfig(ctx context.Context, req *hqStore.DetailStoreTableConfigRequest) (res *hqStore.DetailStoreTableConfigResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailStoreTableConfig(ctx, &store.DetailStoreTableConfigRequest{
		StoreId: req.GetStoreId(),
		BrandId: req.GetBrandId(),
	})
	if err != nil {
		return &hqStore.DetailStoreTableConfigResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}

	data := new(hqStore.StoreTableConfig)
	copier.Copy(&data, r.GetData())

	return &hqStore.DetailStoreTableConfigResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) SetStoreTableLayout(ctx context.Context, req *hqStore.SetStoreTableLayoutRequest) (res *hqStore.SetStoreTableLayoutResponse, err error) {
	newReq := new(store.SetStoreTableLayoutRequest)

	r, err := b.rpcClient.BrandStoreCenter.SetStoreTableLayout(ctx, newReq)
	if err != nil {
		return &hqStore.SetStoreTableLayoutResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.SetStoreTableLayoutResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) CreateStoreTableArea(ctx context.Context, req *hqStore.CreateStoreTableAreaRequest) (res *hqStore.CreateStoreTableAreaResponse, err error) {
	tableAreaList := make([]*store.StoreTableAreaReq, 0)
	for _, v := range req.GetTableAreaList() {
		tableAreaList = append(tableAreaList, &store.StoreTableAreaReq{
			AreaName:       v.GetAreaName(),
			IsTableNoFront: v.GetIsTableNoFront(),
			StartTableNo:   v.GetStartTableNo(),
			TableNum:       v.GetTableNum(),
			TableName:      v.GetTableName(),
			SeatNum:        v.GetSeatNum(),
		})
	}
	r, err := b.rpcClient.BrandStoreCenter.CreateStoreTableArea(ctx, &store.CreateStoreTableAreaRequest{
		StoreId:       req.GetStoreId(),
		BrandId:       req.GetBrandId(),
		TableAreaList: tableAreaList,
	})
	if err != nil {
		return &hqStore.CreateStoreTableAreaResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.CreateStoreTableAreaResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) UpdateStoreTableArea(ctx context.Context, req *hqStore.UpdateStoreTableAreaRequest) (res *hqStore.UpdateStoreTableAreaResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UpdateStoreTableArea(ctx, &store.UpdateStoreTableAreaRequest{
		StoreId:          req.GetStoreId(),
		BrandId:          req.GetBrandId(),
		StoreTableAreaNo: req.GetStoreTableAreaNo(),
		AreaName:         req.GetAreaName(),
	})
	if err != nil {
		return &hqStore.UpdateStoreTableAreaResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.UpdateStoreTableAreaResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DeleteStoreTableArea(ctx context.Context, req *hqStore.DeleteStoreTableAreaRequest) (res *hqStore.DeleteStoreTableAreaResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DeleteStoreTableArea(ctx, &store.DeleteStoreTableAreaRequest{
		BrandId:          req.GetBrandId(),
		StoreId:          req.GetStoreId(),
		StoreTableAreaNo: req.GetStoreTableAreaNo(),
	})
	if err != nil {
		return &hqStore.DeleteStoreTableAreaResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStore.DeleteStoreTableAreaResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) CreateStoreTable(ctx context.Context, req *hqStore.CreateStoreTableRequest) (res *hqStore.CreateStoreTableResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.CreateStoreTable(ctx, &store.CreateStoreTableRequest{
		StoreId:          req.GetStoreId(),
		BrandId:          req.GetBrandId(),
		StoreTableAreaNo: req.GetStoreTableAreaNo(),
		TableName:        req.GetTableName(),
		SeatNum:          req.GetSeatNum(),
	})
	if err != nil {
		return &hqStore.CreateStoreTableResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.CreateStoreTableResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) UpdateStoreTable(ctx context.Context, req *hqStore.UpdateStoreTableRequest) (res *hqStore.UpdateStoreTableResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UpdateStoreTable(ctx, &store.UpdateStoreTableRequest{
		StoreId:          req.GetStoreId(),
		BrandId:          req.GetBrandId(),
		StoreTableNo:     req.GetStoreTableNo(),
		StoreTableAreaNo: req.GetStoreTableAreaNo(),
		TableName:        req.GetTableName(),
		SeatNum:          req.GetSeatNum(),
	})
	if err != nil {
		return &hqStore.UpdateStoreTableResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.UpdateStoreTableResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) DeleteStoreTable(ctx context.Context, req *hqStore.DeleteStoreTableRequest) (res *hqStore.DeleteStoreTableResponse, err error) {
	resp, err := b.rpcClient.BrandStoreCenter.DeleteStoreTable(ctx, &store.DeleteStoreTableRequest{
		StoreId:      req.GetStoreId(),
		BrandId:      req.GetBrandId(),
		StoreTableNo: req.GetStoreTableNo(),
	})
	if err != nil {
		return &hqStore.DeleteStoreTableResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}

	return &hqStore.DeleteStoreTableResponse{
		Code: resp.GetCode(),
		Msg:  resp.GetMsg(),
	}, nil
}

func (b *BrandService) ListStoreTable(ctx context.Context, req *hqStore.ListStoreTableRequest) (res *hqStore.ListStoreTableResponse, err error) {
	resp, err := b.rpcClient.BrandStoreCenter.ListStoreTable(ctx, &store.ListStoreTableRequest{
		StoreId: req.GetStoreId(),
		BrandId: req.GetBrandId(),
	})
	if err != nil {
		return &hqStore.ListStoreTableResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}
	if resp.GetCode() != 0 {
		return &hqStore.ListStoreTableResponse{
			Code: resp.GetCode(),
			Msg:  resp.GetMsg(),
		}, nil
	}
	data := new(hqStore.ListStoreTableResponseData)
	copier.Copy(&data.List, resp.GetData().GetList())
	return &hqStore.ListStoreTableResponse{
		Code: resp.GetCode(),
		Msg:  resp.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) SetStoreBusinessAutoSchedule(ctx context.Context, req *hqStore.SetStoreBusinessAutoScheduleRequest) (res *hqBrandStoreCenter.SetStoreBusinessAutoScheduleResponse, err error) {
	resp, err := b.rpcClient.BrandStoreCenter.SetStoreBusinessAutoSchedule(ctx, &store.SetStoreBusinessAutoScheduleRequest{
		BrandId:     req.GetBrandId(),
		StoreId:     req.GetStoreId(),
		ChannelType: req.GetChannelType(),
		Status:      req.GetStatus(),
		StartTime:   req.GetStartTime(),
		EndTime:     req.GetEndTime(),
	})
	if err != nil {
		return &hqBrandStoreCenter.SetStoreBusinessAutoScheduleResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  err.Error(),
		}, nil
	}
	if resp.GetCode() != 0 {
		return &hqBrandStoreCenter.SetStoreBusinessAutoScheduleResponse{
			Code: resp.GetCode(),
			Msg:  resp.GetMsg(),
		}, nil
	}

	if resp.GetData().GetDelayTime() > 0 { // 发送延迟消息
		payLoad := map[string]interface{}{} //
		_ = payLoad
		_, err = b.rpcClient.MessageCenter.MessageSend(ctx, &messageCenter.MessageSendRequest{
			BizId:      fmt.Sprintf("rms_set_auto_scheduled_storeid_%d", req.GetStoreId()),
			BizType:    "storeBusinessAutoScheduled",
			BizSource:  "rms",
			Payload:    "",
			Exchange:   "rmsStoreBusinessScheduledExchange",
			RoutingKey: ".setBusinessTime.",
			DelayTime:  int64(resp.GetData().GetDelayTime()),
		})
		if err != nil {
			// fixme: 错误处理
		}
	}

	return &hqBrandStoreCenter.SetStoreBusinessAutoScheduleResponse{
		Code: resp.GetCode(),
		Msg:  resp.GetMsg(),
	}, nil
}

func (b *BrandService) DownloadStoreTableCode(ctx context.Context, req *hqStore.DownloadStoreTableCodeRequest) (res *hqStore.DownloadStoreTableCodeResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DownloadStoreTableCode(ctx, &store.DownloadStoreTableCodeRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
		Type:    req.GetType(),
	})
	if err != nil {
		return &hqStore.DownloadStoreTableCodeResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStore.DownloadStoreTableCodeResponseData)
	copier.Copy(data, r.GetData())
	return &hqStore.DownloadStoreTableCodeResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) ListStoreBusinessAutoSchedule(ctx context.Context, req *hqStore.ListStoreBusinessAutoScheduleRequest) (res *hqStore.ListStoreBusinessAutoScheduleResponse, err error) {
	//TODO implement me
	panic("implement me")
}

func (b *BrandService) DetailStoreBusinessAutoSchedule(ctx context.Context, req *hqStore.DetailStoreBusinessAutoScheduleRequest) (res *hqStore.DetailStoreBusinessAutoScheduleResponse, err error) {
	//TODO implement me
	panic("implement me")
}
