package brand_store

import (
	"context"

	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/storedevice"
	"github.com/jinzhu/copier"

	"git.downtown8.com/rms/g-common/g-common/constants/errorcode"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqBrandStoreCenter"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqStoredevice"
)

func (b *BrandService) BindDevice(ctx context.Context, req *hqStoredevice.BindDeviceRequest) (res *hqBrandStoreCenter.BindDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.BindDevice(ctx, &storedevice.BindDeviceRequest{
		DeviceNo:   req.GetDeviceNo(),
		DeviceId:   req.GetDeviceId(),
		DeviceType: "hq-public",
	})
	if err != nil {
		return &hqBrandStoreCenter.BindDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqBrandStoreCenter.BindDeviceResponseData)
	copier.Copy(data, r.GetData())
	return &hqBrandStoreCenter.BindDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UnbindDevice(ctx context.Context, req *hqStoredevice.UnbindDeviceRequest) (res *hqStoredevice.UnbindDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UnbindDevice(ctx, &storedevice.UnbindDeviceRequest{
		StoreId:       req.GetStoreId(),
		BrandId:       req.GetBrandId(),
		StoreDeviceId: req.GetStoreDeviceId(),
	})
	if err != nil {
		return &hqStoredevice.UnbindDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}

	data := new(hqStoredevice.UnbindDeviceResponseData)
	copier.Copy(data, r.GetData())
	return &hqStoredevice.UnbindDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UpsetDevice(ctx context.Context, req *hqStoredevice.UpsetDeviceRequest) (res *hqStoredevice.UpsetDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UpsetDevice(ctx, &storedevice.UpsetDeviceRequest{
		BrandId:       req.GetBrandId(),
		StoreId:       req.GetStoreId(),
		Name:          req.GetName(),
		StoreDeviceId: req.GetStoreDeviceId(),
		DeviceType:    req.GetDeviceType(),
		Status:        req.GetStatus(),
	})
	if err != nil {
		return &hqStoredevice.UpsetDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStoredevice.UpsetDeviceResponseData)
	copier.Copy(data, r.GetData())
	return &hqStoredevice.UpsetDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) ListDevice(ctx context.Context, req *hqStoredevice.ListDeviceRequest) (res *hqStoredevice.ListDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.ListDevice(ctx, &storedevice.ListDeviceRequest{
		StoreId:    req.GetStoreId(),
		BrandId:    req.GetBrandId(),
		Page:       req.GetPage(),
		PageSize:   req.GetPageSize(),
		DeviceType: req.GetDeviceType(),
	})
	if err != nil {
		return &hqStoredevice.ListDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := make([]*hqStoredevice.Device, 0)
	copier.Copy(&data, r.GetData().GetDeviceList())
	return &hqStoredevice.ListDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: &hqStoredevice.ListDeviceResponseData{
			Total:      r.GetData().GetTotal(),
			DeviceList: data,
		},
	}, nil
}

func (b *BrandService) ListDeviceAlreadyBind(ctx context.Context, req *hqStoredevice.ListDeviceAlreadyBindRequest) (res *hqStoredevice.ListDeviceAlreadyBindResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.ListDeviceAlreadyBind(ctx, &storedevice.ListDeviceAlreadyBindRequest{
		StoreId:    req.GetStoreId(),
		BrandId:    req.GetBrandId(),
		DeviceType: req.GetDeviceType(),
	})
	if err != nil {
		return &hqStoredevice.ListDeviceAlreadyBindResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStoredevice.ListDeviceAlreadyBindResponseData)
	copier.Copy(data, r.GetData())
	return &hqStoredevice.ListDeviceAlreadyBindResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) DetailDevice(ctx context.Context, req *hqStoredevice.DetailDeviceRequest) (res *hqBrandStoreCenter.DetailDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DetailDevice(ctx, &storedevice.DetailDeviceRequest{
		DeviceId:   req.GetDeviceId(),
		DeviceType: req.GetDeviceType(),
	})
	if err != nil {
		return &hqBrandStoreCenter.DetailDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqBrandStoreCenter.DetailDeviceResponseData)
	copier.Copy(data, r.GetData())
	return &hqBrandStoreCenter.DetailDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) DeleteDevice(ctx context.Context, req *hqStoredevice.DeleteDeviceRequest) (res *hqStoredevice.DeleteDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.DeleteDevice(ctx, &storedevice.DeleteDeviceRequest{
		StoreId:       req.GetStoreId(),
		BrandId:       req.GetBrandId(),
		StoreDeviceId: req.GetStoreDeviceId(),
	})
	if err != nil {
		return &hqStoredevice.DeleteDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStoredevice.DeleteDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) RefreshDeviceNo(ctx context.Context, req *hqStoredevice.RefreshDeviceNoRequest) (res *hqStoredevice.RefreshDeviceNoResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.RefreshDeviceNo(ctx, &storedevice.RefreshDeviceNoRequest{
		StoreId:       req.GetStoreId(),
		BrandId:       req.GetBrandId(),
		StoreDeviceId: req.GetStoreDeviceId(),
	})
	if err != nil {
		return &hqStoredevice.RefreshDeviceNoResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStoredevice.RefreshDeviceNoResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) CountDevice(ctx context.Context, req *hqStoredevice.CountDeviceRequest) (res *hqStoredevice.CountDeviceResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.CountDevice(ctx, &storedevice.CountDeviceRequest{
		BrandId: req.GetBrandId(),
		StoreId: req.GetStoreId(),
	})
	if err != nil {
		return &hqStoredevice.CountDeviceResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	data := new(hqStoredevice.CountDeviceResponseData)
	copier.Copy(data, r.GetData())
	return &hqStoredevice.CountDeviceResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (b *BrandService) UpdateDeviceAppVersion(ctx context.Context, req *hqStoredevice.UpdateDeviceAppVersionRequest) (res *hqStoredevice.UpdateDeviceAppVersionResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.UpdateDeviceAppVersion(ctx, &storedevice.UpdateDeviceAppVersionRequest{
		DeviceId:   req.GetDeviceId(),
		DeviceType: req.GetDeviceType(),
	})
	if err != nil {
		return &hqStoredevice.UpdateDeviceAppVersionResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStoredevice.UpdateDeviceAppVersionResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}

func (b *BrandService) BindJPushId(ctx context.Context, req *hqStoredevice.BindJPushIdRequest) (res *hqStoredevice.BindJPushIdResponse, err error) {
	r, err := b.rpcClient.BrandStoreCenter.BindJPushId(ctx, &storedevice.BindJPushIdRequest{
		DeviceId:   req.GetDeviceId(),
		DeviceType: req.GetDeviceType(),
		JPushId:    req.GetJPushId(),
	})
	if err != nil {
		return &hqStoredevice.BindJPushIdResponse{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, nil
	}
	return &hqStoredevice.BindJPushIdResponse{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, nil
}
