package product

import (
	"context"
	"git.downtown8.com/rms/g-common/g-common/constants/errorcode"
	"git.downtown8.com/rms/g-product/hera/kitex_gen/saleunit"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqProductCenter/hqproductservice"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqProductSaleUnit"
	"github.com/cloudwego/kitex/server"
)

type Service struct {
	rpcClient *rpcclient.Client
}

func NewProductService(client *rpcclient.Client) *Service {
	o := &Service{
		rpcClient: client,
	}
	return o
}

func RegistryProduct(svc *Service) func(svr server.Server) error {
	return func(svr server.Server) error {
		return hqproductservice.RegisterService(svr, svc)
	}
}

func (s *Service) ImportSuStandard(ctx context.Context, req *hqProductSaleUnit.ImportSuStandardRequest) (res *hqProductSaleUnit.ImportSuStandardResponse, err error) {
	if len(req.GetProductList()) == 0 || req.GetBrandId() == 0 {
		return &hqProductSaleUnit.ImportSuStandardResponse{
			Code: errorcode.PARAMS_ERROR,
			Msg:  errorcode.PARAMS_ERROR_MSG,
		}, nil
	}
	var productList []*saleunit.ImportSuStandardData
	for _, product := range req.GetProductList() {
		var multiPrice []*saleunit.MultiPrice
		for _, v := range product.GetMultiPrice() {
			multiPrice = append(multiPrice, &saleunit.MultiPrice{
				Name:        v.GetName(),
				Price:       v.GetPrice(),
				ProductName: v.GetProductName(),
			})
		}
		productList = append(productList, &saleunit.ImportSuStandardData{
			ProductName:     product.GetProductName(),
			ProductCategory: product.GetProductCategory(),
			Price:           product.GetPrice(),
			ProductUrl:      product.GetProductUrl(),
			MultiPrice:      multiPrice,
		})
	}
	importSuStandardResp, err := s.rpcClient.ProductCenter.ImportSuStandard(ctx, &saleunit.ImportSuStandardReq{
		BrandId:     req.GetBrandId(),
		ProductList: productList,
	})

	if err != nil {
		return &hqProductSaleUnit.ImportSuStandardResponse{
			Code: errorcode.ERR_CODE_NOT_SET,
			Msg:  "导入餐品失败",
		}, nil
	}

	return &hqProductSaleUnit.ImportSuStandardResponse{
		Code: importSuStandardResp.GetCode(),
		Msg:  importSuStandardResp.GetMsg(),
	}, nil
}
