package product

import (
	"context"
	"git.downtown8.com/rms/g-common/g-common/constants/errorcode"
	"git.downtown8.com/rms/g-product/hera/kitex_gen/saleunit"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/hqProductSaleUnit"
	"github.com/jinzhu/copier"
)

func (s *Service) GetSuTagList(ctx context.Context, req *hqProductSaleUnit.GetSuTagListReq) (res *hqProductSaleUnit.GetSuTagListResp, err error) {
	r, err := s.rpcClient.ProductCenter.GetSuTagList(ctx, &saleunit.GetSuTagListReq{
		BrandId:  req.GetBrandId(),
		Page:     req.GetPage(),
		PageSize: req.GetPageSize(),
	})
	if err != nil {
		return &hqProductSaleUnit.GetSuTagListResp{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, err
	}
	data := new(hqProductSaleUnit.GetSuTagListRespData)
	copier.Copy(data, r.GetData())
	return &hqProductSaleUnit.GetSuTagListResp{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (s *Service) SaveSuTag(ctx context.Context, req *hqProductSaleUnit.SaveSuTagReq) (res *hqProductSaleUnit.SaveSuTagResp, err error) {
	var suList []*saleunit.RelationSuList
	for _, v := range req.GetSuList() {
		suList = append(suList, &saleunit.RelationSuList{
			SuNo:   v.GetSuNo(),
			SuType: v.GetSuType(),
			SuName: v.GetSuName(),
		})
	}
	r, err := s.rpcClient.ProductCenter.SaveSuTag(ctx, &saleunit.SaveSuTagReq{
		TagNo:   req.TagNo,
		BrandId: req.GetBrandId(),
		Name:    req.GetName(),
		Color:   req.GetColor(),
		Status:  req.GetStatus(),
		SuList:  suList,
	})
	if err != nil {
		return &hqProductSaleUnit.SaveSuTagResp{
			Code: errorcode.SYSTEM_ERROR,
			Msg:  err.Error(),
		}, err
	}
	data := new(hqProductSaleUnit.SuTag)
	copier.Copy(data, r.GetData())
	return &hqProductSaleUnit.SaveSuTagResp{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
		Data: data,
	}, nil
}

func (s *Service) DeleteSuTag(ctx context.Context, req *hqProductSaleUnit.DeleteSuTagReq) (res *hqProductSaleUnit.DeleteSuTagResp, err error) {
	r, err := s.rpcClient.ProductCenter.DeleteSuTag(ctx, &saleunit.DeleteSuTagReq{
		BrandId: req.GetBrandId(),
		TagNo:   req.GetTagNo(),
	})
	return &hqProductSaleUnit.DeleteSuTagResp{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, err
}

func (s *Service) SortSuTag(ctx context.Context, req *hqProductSaleUnit.SortSuTagReq) (res *hqProductSaleUnit.SortSuTagResp, err error) {
	var items []*saleunit.SortSuTagList
	for _, v := range req.GetItems() {
		items = append(items, &saleunit.SortSuTagList{
			TagNo: v.GetTagNo(),
			Sort:  v.GetSort(),
		})
	}
	r, err := s.rpcClient.ProductCenter.SortSuTag(ctx, &saleunit.SortSuTagReq{
		BrandId: req.GetBrandId(),
		Items:   items,
	})
	return &hqProductSaleUnit.SortSuTagResp{
		Code: r.GetCode(),
		Msg:  r.GetMsg(),
	}, err
}
