package producer

import (
	"context"
	"encoding/json"
)

const (
	baseMessageExchange       = "baseMessage"
	createBrandBaseRoutingKey = "#.base.#"
	rmsBrandExchange          = "rmsBrandExchange"
	updateRoutingKey          = ".update."
	rmsStoreExchange          = "rmsStoreExchange"
	createRoutingKey          = ".create."
)

type CreateBrandPayload struct {
	RuleId  string `json:"ruleId"`
	BizType string `json:"bizType"`
	Payload string `json:"payload"`
}

func (m *RabbitMQProducer) PublishCreateBrand(ctx context.Context, payload *CreateBrandPayload) {
	p, _ := json.Marshal(payload)
	m.publishMq(ctx, p, baseMessageExchange, createBrandBaseRoutingKey)
}

type UpdateBrandPayload struct {
	BrandId   int32  `json:"brandId"`
	BrandName string `json:"brandName"`
	Logo      string `json:"logo"`
	Status    string `json:"status"`
}

func (m *RabbitMQProducer) PublishUpdateBrand(ctx context.Context, payload *UpdateBrandPayload) {
	p, _ := json.Marshal(payload)
	m.publishMq(ctx, p, rmsBrandExchange, updateRoutingKey)
}

type CreateStorePayload struct {
	BrandId   int32  `json:"brandId"`
	StoreId   int32  `json:"storeId"`
	StoreName string `json:"storeName"`
}

func (m *RabbitMQProducer) PublishCreateStore(ctx context.Context, payload *CreateStorePayload) {
	p, _ := json.Marshal(payload)
	m.publishMq(ctx, p, rmsStoreExchange, createRoutingKey)
}
