package brand_store

import (
	"context"
	"errors"

	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/brand"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/brandstorecenter"
	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/sirupsen/logrus"
)

func (c *Center) CreateBrand(ctx context.Context, req *brand.CreateBrandRequest) (res *brand.CreateBrandResponse, err error) {
	r, err := c.rpcCall.CreateBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateBrand error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// listbrand
func (c *Center) ListBrand(ctx context.Context, req *brand.ListBrandRequest) (res *brand.ListBrandResponse, err error) {
	r, err := c.rpcCall.ListBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListBrand error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpdateBrand
func (c *Center) UpdateBrand(ctx context.Context, req *brand.UpdateBrandRequest) (res *brand.UpdateBrandResponse, err error) {
	r, err := c.rpcCall.UpdateBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateBrand error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailBrand
func (c *Center) DetailBrand(ctx context.Context, req *brand.DetailBrandRequest) (res *brand.DetailBrandResponse, err error) {
	r, err := c.rpcCall.DetailBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailBrand error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) DeleteBrand(ctx context.Context, req *brand.DeleteBrandRequest) (res *brand.DeleteBrandResponse, err error) {
	r, err := c.rpcCall.DeleteBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteBrand error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListBrandWithStoreCnt
func (c *Center) ListBrandWithStoreCnt(ctx context.Context, req *brandstorecenter.ListBrandWithStoreCntRequest) (res *brandstorecenter.ListBrandWithStoreCntResponse, err error) {
	r, err := c.rpcCall.ListBrandWithStoreCnt(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListBrandWithStoreCnt error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListBrandWithStoreCnt error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// CreateOpenBrand
func (c *Center) CreateOpenBrand(ctx context.Context, req *brand.CreateOpenBrandRequest) (res *brand.CreateOpenBrandResponse, err error) {
	r, err := c.rpcCall.CreateOpenBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateOpenBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateOpenBrand error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
