package brand_store

import (
	"context"
	"errors"
	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/brandstorecenter"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/store"
	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/sirupsen/logrus"
)

// CreateStore
func (c *Center) CreateStore(ctx context.Context, req *store.CreateStoreRequest) (res *store.CreateStoreResponse, err error) {
	r, err := c.rpcCall.CreateStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStore error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// CreateOpenStore
func (c *Center) CreateOpenStore(ctx context.Context, req *store.CreateOpenStoreRequest) (res *store.CreateOpenStoreResponse, err error) {
	r, err := c.rpcCall.CreateOpenStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateOpenStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateOpenStore error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListStore
func (c *Center) ListStore(ctx context.Context, req *store.ListStoreRequest) (res *store.ListStoreResponse, err error) {
	r, err := c.rpcCall.ListStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListStore error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListStoreWithDeleted
func (c *Center) ListStoreWithDeleted(ctx context.Context, req *store.ListStoreWithDeletedRequest) (res *store.ListStoreWithDeletedResponse, err error) {
	r, err := c.rpcCall.ListStoreWithDeleted(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreWithDeleted error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreWithDeleted error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpdateStore
func (c *Center) UpdateStore(ctx context.Context, req *store.UpdateStoreRequest) (res *store.UpdateStoreResponse, err error) {
	r, err := c.rpcCall.UpdateStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStore error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpdateStorePlate
func (c *Center) UpdateStorePlate(ctx context.Context, req *store.StorePlateRequest) (res *store.StorePlateResponse, err error) {
	r, err := c.rpcCall.UpdateStorePlate(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStorePlate error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStorePlate error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DeleteStore
func (c *Center) DeleteStore(ctx context.Context, req *store.DeleteStoreRequest) (res *store.DeleteStoreResponse, err error) {
	r, err := c.rpcCall.DeleteStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStore error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailStore
func (c *Center) DetailStore(ctx context.Context, req *store.DetailStoreRequest) (res *store.DetailStoreResponse, err error) {
	r, err := c.rpcCall.DetailStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStore error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailStoreWithBusiness
func (c *Center) DetailStoreWithBusiness(ctx context.Context, req *store.DetailStoreWithBusinessRequest) (res *store.DetailStoreWithBusinessResponse, err error) {
	r, err := c.rpcCall.DetailStoreWithBusiness(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreWithBusiness error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreWithBusiness error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpdateStoreOrderMethod
func (c *Center) UpdateStoreOrderMethod(ctx context.Context, req *store.UpdateStoreOrderMethodRequest) (res *store.UpdateStoreOrderMethodResponse, err error) {
	r, err := c.rpcCall.UpdateStoreOrderMethod(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreOrderMethod error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreOrderMethod error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailStoreStatus
func (c *Center) DetailStoreStatus(ctx context.Context, req *brandstorecenter.DetailStoreStatusRequest) (res *brandstorecenter.DetailStoreStatusResponse, err error) {
	r, err := c.rpcCall.DetailStoreStatus(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreStatus error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreStatus error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DownloadStoreCode
func (c *Center) DownloadStoreCode(ctx context.Context, req *store.DownloadStoreCodeRequest) (res *store.DownloadStoreCodeResponse, err error) {
	r, err := c.rpcCall.DownloadStoreCode(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DownloadStoreCode error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DownloadStoreCode error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UploadBusinessQualifications
func (c *Center) UploadBusinessQualifications(ctx context.Context, req *store.UploadBusinessQualificationsRequest) (res *store.UploadBusinessQualificationsResponse, err error) {
	r, err := c.rpcCall.UploadBusinessQualifications(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UploadBusinessQualifications error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UploadBusinessQualifications error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// SetOrderPath
func (c *Center) SetOrderPath(ctx context.Context, req *store.SetOrderPathRequest) (res *store.SetOrderPathResponse, err error) {
	r, err := c.rpcCall.SetOrderPath(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SetOrderPath error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SetOrderPath error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
