package brand_store

import (
	"context"
	"errors"

	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/store"
	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/sirupsen/logrus"
)

func (c *Center) CreateStoreTableArea(ctx context.Context, req *store.CreateStoreTableAreaRequest) (*store.CreateStoreTableAreaResponse, error) {
	r, err := c.rpcCall.CreateStoreTableArea(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStoreTableArea error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStoreTableArea error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) UpdateStoreTableArea(ctx context.Context, req *store.UpdateStoreTableAreaRequest) (*store.UpdateStoreTableAreaResponse, error) {
	r, err := c.rpcCall.UpdateStoreTableArea(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreTableArea error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreTableArea error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) DeleteStoreTableArea(ctx context.Context, req *store.DeleteStoreTableAreaRequest) (*store.DeleteStoreTableAreaResponse, error) {
	r, err := c.rpcCall.DeleteStoreTableArea(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStoreTableArea error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStoreTableArea error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) CreateStoreTable(ctx context.Context, req *store.CreateStoreTableRequest) (*store.CreateStoreTableResponse, error) {
	r, err := c.rpcCall.CreateStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) UpdateStoreTable(ctx context.Context, req *store.UpdateStoreTableRequest) (*store.UpdateStoreTableResponse, error) {
	r, err := c.rpcCall.UpdateStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) DeleteStoreTable(ctx context.Context, req *store.DeleteStoreTableRequest) (*store.DeleteStoreTableResponse, error) {
	r, err := c.rpcCall.DeleteStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) ListStoreTable(ctx context.Context, req *store.ListStoreTableRequest) (res *store.ListStoreTableResponse, err error) {
	r, err := c.rpcCall.ListStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailStoreBusiness
func (c *Center) DetailStoreBusiness(ctx context.Context, req *store.DetailStoreBusinessRequest) (res *store.DetailStoreBusinessResponse, err error) {
	r, err := c.rpcCall.DetailStoreBusiness(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreBusiness error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreBusiness error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListStoreBusiness
func (c *Center) ListStoreBusiness(ctx context.Context, req *store.ListStoreBusinessRequest) (res *store.ListStoreBusinessResponse, err error) {
	r, err := c.rpcCall.ListStoreBusiness(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreBusiness error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreBusiness error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpdateStoreBusiness
func (c *Center) UpdateStoreBusiness(ctx context.Context, req *store.UpdateStoreBusinessRequest) (res *store.UpdateStoreBusinessResponse, err error) {
	r, err := c.rpcCall.UpdateStoreBusiness(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreBusiness error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateStoreBusiness error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// CreateStoreBusiness
func (c *Center) CreateStoreBusiness(ctx context.Context, req *store.CreateStoreBusinessRequest) (res *store.CreateStoreBusinessResponse, err error) {
	r, err := c.rpcCall.CreateStoreBusiness(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStoreBusiness error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateStoreBusiness error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DeleteStoreBusiness
func (c *Center) DeleteStoreBusiness(ctx context.Context, req *store.DeleteStoreBusinessRequest) (res *store.DeleteStoreBusinessResponse, err error) {
	r, err := c.rpcCall.DeleteStoreBusiness(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStoreBusiness error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteStoreBusiness error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// SetStoreBusinessStatus
func (c *Center) SetStoreBusinessAutoSchedule(ctx context.Context, req *store.SetStoreBusinessAutoScheduleRequest) (res *store.SetStoreBusinessAutoScheduleResponse, err error) {
	r, err := c.rpcCall.SetStoreBusinessAutoSchedule(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SetStoreBusinessAutoSchedule error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SetStoreBusinessAutoSchedule error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListStoreBusinessStatus
func (c *Center) ListStoreBusinessAutoSchedule(ctx context.Context, req *store.ListStoreBusinessAutoScheduleRequest) (res *store.ListStoreBusinessAutoScheduleResponse, err error) {
	r, err := c.rpcCall.ListStoreBusinessAutoSchedule(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreBusinessAutoSchedule error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListStoreBusinessAutoSchedule error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailStoreBusinessStatus
func (c *Center) DetailStoreBusinessAutoSchedule(ctx context.Context, req *store.DetailStoreBusinessAutoScheduleRequest) (res *store.DetailStoreBusinessAutoScheduleResponse, err error) {
	r, err := c.rpcCall.DetailStoreBusinessAutoSchedule(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreBusinessAutoSchedule error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreBusinessAutoSchedule error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// SetStoreTableConfig
func (c *Center) SetStoreTableConfig(ctx context.Context, req *store.SetStoreTableConfigRequest) (res *store.SetStoreTableConfigResponse, err error) {
	r, err := c.rpcCall.SetStoreTableConfig(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SetStoreTableConfig error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SetStoreTableConfig error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailStoreTableConfig
func (c *Center) DetailStoreTableConfig(ctx context.Context, req *store.DetailStoreTableConfigRequest) (res *store.DetailStoreTableConfigResponse, err error) {
	r, err := c.rpcCall.DetailStoreTableConfig(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreTableConfig error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailStoreTableConfig error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// SetStoreTableLayout
func (c *Center) SetStoreTableLayout(ctx context.Context, req *store.SetStoreTableLayoutRequest) (res *store.SetStoreTableLayoutResponse, err error) {
	r, err := c.rpcCall.SetStoreTableLayout(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SetStoreTableLayout error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SetStoreTableLayout error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// TakeStoreTable
func (c *Center) TakeStoreTable(ctx context.Context, req *store.TakeStoreTableRequest) (res *store.TakeStoreTableResponse, err error) {
	r, err := c.rpcCall.TakeStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call TakeStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call TakeStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// CancelTakeStoreTable
func (c *Center) CancelTakeStoreTable(ctx context.Context, req *store.CancelTakeStoreTableRequest) (res *store.CancelTakeStoreTableResponse, err error) {
	r, err := c.rpcCall.CancelTakeStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CancelTakeStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CancelTakeStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ChangeStoreTable
func (c *Center) ChangeStoreTable(ctx context.Context, req *store.ChangeStoreTableRequest) (res *store.ChangeStoreTableResponse, err error) {
	r, err := c.rpcCall.ChangeStoreTable(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ChangeStoreTable error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ChangeStoreTable error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DownloadStoreCode
func (c *Center) DownloadStoreTableCode(ctx context.Context, req *store.DownloadStoreTableCodeRequest) (res *store.DownloadStoreTableCodeResponse, err error) {
	r, err := c.rpcCall.DownloadStoreTableCode(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DownloadStoreCode error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DownloadStoreCode error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
