package brand_store

import (
	"context"
	"errors"

	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/brandstorecenter"
	"git.downtown8.com/rms/g-brand-store/hera/kitex_gen/storedevice"
	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/sirupsen/logrus"
)

// BindDevice
func (c *Center) BindDevice(ctx context.Context, req *storedevice.BindDeviceRequest) (res *brandstorecenter.BindDeviceResponse, err error) {
	r, err := c.rpcCall.BindDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call BindDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call BindDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UnbindDevice
func (c *Center) UnbindDevice(ctx context.Context, req *storedevice.UnbindDeviceRequest) (res *storedevice.UnbindDeviceResponse, err error) {
	r, err := c.rpcCall.UnbindDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UnbindDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UnbindDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpsetDevice
func (c *Center) UpsetDevice(ctx context.Context, req *storedevice.UpsetDeviceRequest) (res *storedevice.UpsetDeviceResponse, err error) {
	r, err := c.rpcCall.UpsetDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpsetDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpsetDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListDevice
func (c *Center) ListDevice(ctx context.Context, req *storedevice.ListDeviceRequest) (res *storedevice.ListDeviceResponse, err error) {
	r, err := c.rpcCall.ListDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// ListDeviceAlreadyBind
func (c *Center) ListDeviceAlreadyBind(ctx context.Context, req *storedevice.ListDeviceAlreadyBindRequest) (res *storedevice.ListDeviceAlreadyBindResponse, err error) {
	r, err := c.rpcCall.ListDeviceAlreadyBind(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call ListDeviceAlreadyBind error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call ListDeviceAlreadyBind error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailDevice
func (c *Center) DetailDevice(ctx context.Context, req *storedevice.DetailDeviceRequest) (res *brandstorecenter.DetailDeviceResponse, err error) {
	r, err := c.rpcCall.DetailDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DeleteDevice
func (c *Center) DeleteDevice(ctx context.Context, req *storedevice.DeleteDeviceRequest) (res *storedevice.DeleteDeviceResponse, err error) {
	r, err := c.rpcCall.DeleteDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// RefreshDeviceNo
func (c *Center) RefreshDeviceNo(ctx context.Context, req *storedevice.RefreshDeviceNoRequest) (res *storedevice.RefreshDeviceNoResponse, err error) {
	r, err := c.rpcCall.RefreshDeviceNo(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call RefreshDeviceNo error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call RefreshDeviceNo error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// PosSetting
func (c *Center) PosSetting(ctx context.Context, req *brandstorecenter.PosSettingRequest) (res *brandstorecenter.PosSettingResponse, err error) {
	r, err := c.rpcCall.PosSetting(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call PosSetting error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call PosSetting error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// SettingDeviceVoice
func (c *Center) SettingDeviceVoice(ctx context.Context, req *storedevice.SettingDeviceVoiceRequest) (res *storedevice.SettingDeviceVoiceResponse, err error) {
	r, err := c.rpcCall.SettingDeviceVoice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SettingDeviceVoice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SettingDeviceVoice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// DetailDeviceVoice
func (c *Center) DetailDeviceVoice(ctx context.Context, req *storedevice.DetailDeviceVoiceRequest) (res *storedevice.DetailDeviceVoiceResponse, err error) {
	r, err := c.rpcCall.DetailDeviceVoice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DetailDeviceVoice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DetailDeviceVoice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// CountDevice
func (c *Center) CountDevice(ctx context.Context, req *storedevice.CountDeviceRequest) (res *storedevice.CountDeviceResponse, err error) {
	r, err := c.rpcCall.CountDevice(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CountDevice error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CountDevice error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// UpdateDeviceAppVersion
func (c *Center) UpdateDeviceAppVersion(ctx context.Context, req *storedevice.UpdateDeviceAppVersionRequest) (res *storedevice.UpdateDeviceAppVersionResponse, err error) {
	r, err := c.rpcCall.UpdateDeviceAppVersion(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateDeviceAppVersion error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateDeviceAppVersion error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// BindJPushId
func (c *Center) BindJPushId(ctx context.Context, req *storedevice.BindJPushIdRequest) (res *storedevice.BindJPushIdResponse, err error) {
	r, err := c.rpcCall.BindJPushId(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call BindJPushId error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call BindJPushId error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
