package rpcclient

import (
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/config"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/brand_store"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/kitchen"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/message_center"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/middle/printer"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/onlinesales"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/order"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/product"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/public"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/rpcclient/user"
	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/google/wire"
)

type Client struct {
	BrandStoreCenter  *brand_store.Center
	OrderCenter       *order.Center
	KitchenCenter     *kitchen.Center
	MessageCenter     *message_center.Center
	ProductCenter     *product.Center
	UserCenter        *user.Center
	PublicCenter      *public.Center
	OnlineSalesCenter *onlinesales.Center
	PrintCenter       *printer.Center
}

var ProviderSet = wire.NewSet(New)

func New(c config.Config) *Client {
	orderCenterClient := order.New(c)
	productCenterClient := product.New(c)
	kitchenCenterClient := kitchen.New(c)
	brandStoreCenter := brand_store.New(c)
	messageCenterClient := message_center.New(c)
	userCenterClient := user.New(c)
	publicCenterClient := public.New(c)
	onlinesalesClient := onlinesales.New(c)
	printerClient := printer.New(c)

	return &Client{
		OrderCenter:       orderCenterClient,
		ProductCenter:     productCenterClient,
		KitchenCenter:     kitchenCenterClient,
		BrandStoreCenter:  brandStoreCenter,
		MessageCenter:     messageCenterClient,
		UserCenter:        userCenterClient,
		PublicCenter:      publicCenterClient,
		OnlineSalesCenter: onlinesalesClient,
		PrintCenter:       printerClient,
	}
}
