package kitchen

import (
	"context"
	"errors"
	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-kitchen/hera/kitex_gen/kitchenworkstation"
	"github.com/sirupsen/logrus"
)

func (c *Center) List(ctx context.Context, req *kitchenworkstation.ListRequest) (*kitchenworkstation.ListResponse, error) {
	r, err := c.rpcCall.List(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call List error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call List error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) CountKitchenReceiptPrinterRule(ctx context.Context, req *kitchenworkstation.CountKitchenReceiptPrinterRuleRequest) (*kitchenworkstation.CountKitchenReceiptPrinterRuleResponse, error) {
	r, err := c.rpcCall.CountKitchenReceiptPrinterRule(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CountKitchenReceiptPrinterRule error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CountKitchenReceiptPrinterRule error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
