package message_center

import (
	"context"
	"errors"
	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-mq/hera/kitex_gen/messageCenter"
	"github.com/sirupsen/logrus"
)

func (c *Center) MessageSend(ctx context.Context, req *messageCenter.MessageSendRequest) (*messageCenter.MessageSendResponse, error) {
	r, err := c.rpcCall.MessageSend(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call MessageSend error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call MessageSend error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) MessageNotify(ctx context.Context, req *messageCenter.MessageNotifyRequest) (*messageCenter.MessageNotifyResponse, error) {
	r, err := c.rpcCall.MessageNotify(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call MessageNotify error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call MessageNotify error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
