package printer

import (
	"context"
	"errors"
	"fmt"
	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/middleplatform/printer"

	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/sirupsen/logrus"
)

func (c *Center) QueryPrinter(ctx context.Context, req *printer.QueryPrinterReq) ([]*printer.Printer, error) {
	if len(req.GetPrinterIds()) == 0 {
		return nil, errors.New("打印机不能为空")
	}
	r, err := c.rpcCall.QueryPrinter(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call QueryPrinter error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call QueryPrinter error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r.GetData(), nil
}

func (c *Center) CopyPrinter(ctx context.Context, req *printer.CopyPrinterReq) (*printer.Printer, error) {
	if req.GetPrinterId() == "" {
		return nil, errors.New("打印机不存在")
	}
	r, err := c.rpcCall.CopyPrinter(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CopyPrinter error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CopyPrinter error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r.GetData(), nil
}

func (c *Center) DelPrinter(ctx context.Context, req *printer.DelPrinterReq) error {
	if req.GetPrinterId() == "" {
		return errors.New("打印机不存在")
	}
	r, err := c.rpcCall.DelPrinter(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DelPrinter error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DelPrinter error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return nil
}

func (c *Center) SavePrinter(ctx context.Context, req *printer.SavePrinterReq) (*printer.Printer, error) {
	r, err := c.rpcCall.SavePrinter(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SavePrinter error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SavePrinter error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r.GetData(), nil
}

func (c *Center) CreatePrintTask(ctx context.Context, req *printer.CreatePrintTaskReq) error {
	r, err := c.rpcCall.CreatePrintTask(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreatePrintTask error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreatePrintTask error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
		return fmt.Errorf("CreatePrintTask failed, code: %d, msg: %s", r.GetCode(), r.GetMsg())
	}
	return nil
}
