package onlinesales

import (
	"context"
	"errors"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/moduleModel"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/kitex_gen/onlineSalesWorkflow"

	"git.downtown8.com/golang/common/onelog"
	"github.com/sirupsen/logrus"
)

// 赠送授权
func (c *Center) GiveAuthPackage(ctx context.Context, req *moduleModel.GiveAuthPackageRequest) (*moduleModel.GiveAuthPackageResponse, error) {
	r, err := c.rpcCall.GiveAuthPackage(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call GiveAuthPackage error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call GiveAuthPackage error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// 获取赠送授权
func (c *Center) GetGiveAuthStatus(ctx context.Context, req *moduleModel.GetGiveAuthStatus) (*moduleModel.GetGiveAuthStatusResponse, error) {
	r, err := c.rpcCall.GetGiveAuthStatus(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call GetGiveAuthStatus error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call GetGiveAuthStatus error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// 查询品牌门店授权模块列表
func (c *Center) GetStoreModule(ctx context.Context, req *moduleModel.GetStoreStoreModuleRequest) (*moduleModel.GetStoreStoreModuleResponse, error) {
	r, err := c.rpcCall.GetStoreModule(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call GetStoreModule error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call GetStoreModule error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

// 判断门店是否购买过授权
func (c *Center) JudgePurchaseAuthStore(ctx context.Context, req *onlineSalesWorkflow.JudgePurchaseAuthStoreRequest) (*onlineSalesWorkflow.JudgePurchaseAuthStoreResponse, error) {
	r, err := c.rpcCall.JudgePurchaseAuthStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call JudgePurchaseAuthStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call JudgePurchaseAuthStore error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
