package order

import (
	"context"
	"errors"
	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-orders/hera/kitex_gen/orderconfig"
	_ "github.com/cloudwego/kitex/pkg/remote/codec/protobuf/encoding/gzip"
	"github.com/sirupsen/logrus"
)

func (c *Center) CreateOrderReceipt(ctx context.Context, req *orderconfig.CreateOrderReceiptReq) (*orderconfig.CreateOrderReceiptResp, error) {
	r, err := c.rpcCall.CreateOrderReceipt(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CreateOrderReceipt error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CreateOrderReceipt error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) GetOrderReceiptList(ctx context.Context, req *orderconfig.GetOrderReceiptListReq) (*orderconfig.GetOrderReceiptListResp, error) {
	r, err := c.rpcCall.GetOrderReceiptList(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call GetOrderReceiptList error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call GetOrderReceiptList error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) DelOrderReceipt(ctx context.Context, req *orderconfig.DelOrderReceiptReq) (*orderconfig.DelOrderReceiptResp, error) {
	r, err := c.rpcCall.DelOrderReceipt(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DelOrderReceipt error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DelOrderReceipt error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) UpdateOrderReceipt(ctx context.Context, req *orderconfig.UpdateOrderReceiptReq) (*orderconfig.UpdateOrderReceiptResp, error) {
	r, err := c.rpcCall.UpdateOrderReceipt(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateOrderReceipt error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call UpdateOrderReceipt error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) CountOrderReceipt(ctx context.Context, req *orderconfig.CountOrderReceiptReq) (*orderconfig.CountOrderReceiptResp, error) {
	r, err := c.rpcCall.CountOrderReceipt(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CountOrderReceipt error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CountOrderReceipt error", logrus.Fields{
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
