package product

import (
	"context"
	"errors"
	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/g-product/hera/kitex_gen/saleunit"
	"github.com/sirupsen/logrus"
)

func (c *Center) SortSuTag(ctx context.Context, req *saleunit.SortSuTagReq) (*saleunit.SortSuTagResp, error) {
	r, err := c.rpcCall.SortSuTag(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SortSuTag error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}

	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SortSuTag error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) SaveSuTag(ctx context.Context, req *saleunit.SaveSuTagReq) (*saleunit.SaveSuTagResp, error) {
	r, err := c.rpcCall.SaveSuTag(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call SaveSuTag error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}

	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call SaveSuTag error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) GetSuTagList(ctx context.Context, req *saleunit.GetSuTagListReq) (*saleunit.GetSuTagListResp, error) {
	r, err := c.rpcCall.GetSuTagList(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call GetSuTagList error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}

	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call GetSuTagList error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}

func (c *Center) DeleteSuTag(ctx context.Context, req *saleunit.DeleteSuTagReq) (*saleunit.DeleteSuTagResp, error) {
	r, err := c.rpcCall.DeleteSuTag(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteSuTag error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}

	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call DeleteSuTag error", logrus.Fields{
			"err":  err,
			"req":  req,
			"code": r.GetCode(),
			"msg":  r.GetMsg(),
		})
	}
	return r, nil
}
