package user

import (
	"context"
	"fmt"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userCenter/userservice"

	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userCenter/userpermitservice"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/config"
	"github.com/cloudwego/kitex/client"
	"github.com/cloudwego/kitex/pkg/endpoint"
	"github.com/cloudwego/kitex/pkg/rpcinfo"
	"github.com/cloudwego/kitex/transport"
	"google.golang.org/grpc/metadata"
)

type Center struct {
	userPermit userpermitservice.Client
	user       userservice.Client
}

func New(c config.Config) *Center {
	userPermit := userpermitservice.MustNewClient(c.UserCenterSvc.Name, client.WithTransportProtocol(transport.GRPC),
		client.WithHostPorts(fmt.Sprintf("%s:%d", c.UserCenterSvc.Addr, c.UserCenterSvc.Port)),
		client.WithClientBasicInfo(&rpcinfo.EndpointBasicInfo{ServiceName: c.Application.Name}),
		client.WithMiddleware(func(next endpoint.Endpoint) endpoint.Endpoint {
			return func(ctx context.Context, req, resp interface{}) (err error) {
				md, ok := metadata.FromIncomingContext(ctx)
				if ok {
					ctx = metadata.NewOutgoingContext(ctx, md)
				}
				return next(ctx, req, resp)
			}
		}),
	)
	user := userservice.MustNewClient(c.UserCenterSvc.Name, client.WithTransportProtocol(transport.GRPC),
		client.WithHostPorts(fmt.Sprintf("%s:%d", c.UserCenterSvc.Addr, c.UserCenterSvc.Port)),
		client.WithClientBasicInfo(&rpcinfo.EndpointBasicInfo{ServiceName: c.Application.Name}),
		client.WithMiddleware(func(next endpoint.Endpoint) endpoint.Endpoint {
			return func(ctx context.Context, req, resp interface{}) (err error) {
				md, ok := metadata.FromIncomingContext(ctx)
				if ok {
					ctx = metadata.NewOutgoingContext(ctx, md)
				}
				return next(ctx, req, resp)
			}
		}),
	)
	return &Center{userPermit: userPermit, user: user}
}
