package user

import (
	"context"
	"errors"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userCenter"
	"git.downtown8.com/baseplatform/user-center/hera/kitex_gen/userpermit"

	"git.downtown8.com/golang/common/onelog"
	"github.com/sirupsen/logrus"
)

// 查询用户信息
func (c *Center) HqUserInfo(ctx context.Context, req *userCenter.UserCenterHqUserInfoReq) (*userCenter.UserCenterHqUserInfoResp, error) {
	r, err := c.user.HqUserInfo(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call HqUserInfo error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call HqUserInfo business error", logrus.Fields{
			"err": err,
			"req": req,
		})
	}
	return r, nil
}

// 初始化品牌权限
func (c *Center) InitUserBrand(ctx context.Context, req *userCenter.UserCenterInitUserBrandReq) (*userCenter.UserCenterInitUserBrandResp, error) {
	r, err := c.user.InitUserBrand(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call InitUserBrand error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call InitUserBrand business error", logrus.Fields{
			"err": err,
			"req": req,
		})
	}
	return r, nil
}

// 当前用户的权限
func (c *Center) CurrentUserBrandStoresV3(ctx context.Context, req *userpermit.CurrentUserBrandStoresRequest) (*userpermit.CurrentUserBrandStoresResponse, error) {
	r, err := c.userPermit.CurrentUserBrandStoresV3(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call CurrentUserBrandStoresV3 error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call CurrentUserBrandStoresV3 error", logrus.Fields{
			"err": err,
			"req": req,
		})
	}
	return r, nil
}

// 初始化门店权限
func (c *Center) InitUserStore(ctx context.Context, req *userCenter.UserCenterInitUserStoreReq) (*userCenter.UserCenterInitUserStoreResp, error) {
	r, err := c.user.InitUserStore(ctx, req)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "rpc call InitUserStore error", logrus.Fields{
			"err": err,
			"req": req,
		})
		return nil, errors.New("server error")
	}
	if r.GetCode() != 0 {
		onelog.CtxErrorOptions(ctx, "rpc call InitUserStore business error", logrus.Fields{
			"err": err,
			"req": req,
		})
	}
	return r, nil
}
