package rpc

import (
	"github.com/kitex-contrib/obs-opentelemetry/tracing"
	"net"

	"git.downtown8.com/golang/common/middleware"

	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/config"
	"github.com/cloudwego/kitex/pkg/rpcinfo"
	"github.com/cloudwego/kitex/server"
	"github.com/google/wire"
)

type KitexServer struct {
	cfg config.Config
	svr server.Server
}

var ProviderSet = wire.NewSet(New)

func New(cfg config.Config, registryFunc ...func(server.Server) error) (*KitexServer, error) {
	ks := &KitexServer{
		cfg: cfg,
	}
	err := ks.listen()
	if err != nil {
		return nil, err
	}
	ks.registerService(registryFunc...)
	return ks, nil
}

func (s *KitexServer) listen() error {
	addr, err := net.ResolveTCPAddr("tcp", s.cfg.Application.Host)
	if err != nil {
		return err
	}
	svr := server.NewServer(server.WithServiceAddr(addr),
		server.WithSuite(tracing.NewServerSuite(tracing.WithEnableMetadata())),
		server.WithServerBasicInfo(&rpcinfo.EndpointBasicInfo{ServiceName: s.cfg.Application.Name}),
		server.WithMiddleware(middleware.LoggingMiddleware),
	)

	s.svr = svr
	return nil
}

func (s *KitexServer) registerService(registryFunc ...func(server.Server) error) {
	for _, fn := range registryFunc {
		err := fn(s.svr)
		if err != nil {
			panic(err)
		}
	}
}

func (s *KitexServer) Serve() error {
	return s.svr.Run()
}
