package novu

import (
	"context"
	"fmt"
	"net/url"

	"git.downtown8.com/golang/common/onelog"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/config"
	"github.com/google/wire"
	novu "github.com/novuhq/go-novu/lib"
	"github.com/sirupsen/logrus"
)

type Novu struct {
	client *novu.APIClient
	prefix string
}

var ProviderSet = wire.NewSet(New)

func New(config config.Config) *Novu {
	apiUrl, _ := url.Parse(config.Novu.BackendURL)
	novuClient := novu.NewAPIClient(config.Novu.ApiKey,
		&novu.Config{BackendURL: apiUrl})

	return &Novu{
		client: novuClient,
		prefix: config.Novu.SubscriberPrefix,
	}
}

func (n *Novu) Publish(ctx context.Context, triggerName string, storeId int32, traceId string, payload interface{}) error {
	to := map[string]interface{}{
		"subscriberId": fmt.Sprintf("%s%d", n.prefix, storeId),
	}

	data := novu.ITriggerPayloadOptions{To: to, Payload: payload, TransactionId: traceId}

	// 触发通知事件
	response, err := n.client.EventApi.Trigger(ctx, triggerName, data)
	if err != nil {
		onelog.CtxErrorOptions(ctx, "publish novu error", logrus.Fields{
			"err":     err,
			"payload": payload,
		})
		return err
	}
	onelog.CtxInfoOptions(ctx, "publish novu success", logrus.Fields{
		"response":    response,
		"triggerName": triggerName,
		"storeId":     storeId,
		"payload":     payload,
	})

	return nil
}
