package main

import (
	"flag"
	"fmt"
	"git.downtown8.com/rms/g-common/g-common/metrics"
	"os"

	"git.downtown8.com/golang/common/onelog"
	kitexlogrus "git.downtown8.com/golang/common/onelogrus"
	"git.downtown8.com/rms/orchestrator/g-hq-orchestrator/internal/config"
)

var configFile = flag.String("f", "etc/config.yaml", "the config file")

func main() {
	c := config.Load(*configFile)

	onelog.SetLogger(kitexlogrus.NewLogger())
	onelog.SetLevel(onelog.LevelInfo)

	clean := metrics.New(c.Otel)
	defer clean()

	kitexSvr, _, err := initApp(c)
	if err != nil {
		onelog.Error(err.Error())
	}

	defer func() {
		if r := recover(); r != nil {
			fmt.Println("Recovered in f", r)
			os.Exit(1)
		}
	}()

	err = kitexSvr.Serve()
	if err != nil {
		onelog.Error(err.Error())
	}
}
